@@ -1,7 +1,9 @@
 import os
 from typing import Union, Any, Iterable
 
-from .imports import mock, doctest
+from minimock import mock
+import doctest
+import logging as log
 
 try:
     import tomllib
@@ -27,15 +29,15 @@ def tomlrc(
         - a list of strings (ie. `tomlrc(["tool", "example", "table"])`)
         - combinations of the above
     >>> tomlrc("tool", filename=None)
-    ({'example': {'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}}}, 'tool')
+    ({'example': {'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}, 'empty': {'table': {}}}}, 'tool')
     >>> tomlrc(["tool"], filename=None)
-    ({'example': {'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}}}, 'tool')
+    ({'example': {'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}, 'empty': {'table': {}}}}, 'tool')
     >>> tomlrc("tool", "example", filename=None)
-    ({'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}}, 'tool.example')
+    ({'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}, 'empty': {'table': {}}}, 'tool.example')
     >>> tomlrc(["tool", "example"], filename=None)
-    ({'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}}, 'tool.example')
+    ({'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}, 'empty': {'table': {}}}, 'tool.example')
     >>> tomlrc(["tool"], "example", filename=None)
-    ({'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}}, 'tool.example')
+    ({'first': 1, 'second': 2, 'table': {'lorem': 'ipsum'}, 'deeply': {'nested': {'table': {'ie': 'ex'}}}, 'empty': {'table': {}}}, 'tool.example')
     >>> tomlrc(["tool.example"], "deeply", "nested", filename=None)
     ({'table': {'ie': 'ex'}}, 'tool.example.deeply.nested')
     >>> tomlrc(["tool.example"], ["deeply", "nested"], filename=None)
@@ -51,11 +53,13 @@ def tomlrc(
     >>> tomlrc(["tool.example"], ["table.lorem"], filename=None)
     Traceback (most recent call last):
     ...
-    ValueError: Key provided 'tool.example.table.lorem' does not correspond to a table: 'ipsum'
+    KeyError: "Key provided corresponds to a value, not a table: tool.example.table.lorem = 'ipsum'"
+    >>> tomlrc(["tool.example.empty.table"], filename=None)
+    ({}, 'tool.example.empty.table')
     >>> tomlrc(["tool.sample"], filename=None)
-    Traceback (most recent call last):
-    ...
-    ValueError: The table 'tool.sample' does not exist in the TOML file
+    ({}, 'tool.sample')
+    >>> tomlrc(["tool.sample.even.deeper"], filename=None)
+    ({}, 'tool.sample.even.deeper')
     """
 
     def flatten_path(path: Iterable[Union[str, list[str]]]) -> list[str]:
@@ -83,6 +87,8 @@ def tomlrc(
             
             [tool.example.deeply.nested.table]
             ie = "ex"
+            
+            [tool.example.empty.table]
         """
     else:
         contents = read(filename)
@@ -91,16 +97,18 @@ def tomlrc(
     flattened: list[str] = flatten_path(path)
 
     for key, index in indexed(flattened):
-        try:
-            toml = toml[key]
-        except KeyError:
-            raise ValueError(
-                f"The table '{'.'.join(flattened[:index+1])}' does not exist in the TOML file"
-            )
+        if toml:
+            try:
+                toml = toml[key]
+            except KeyError:
+                log.warning(
+                    f"The table '{'.'.join(flattened[:index+1])}' does not exist in the TOML file"
+                )
+                toml = {}
 
     if not isinstance(toml, dict):
-        raise ValueError(
-            f"Key provided '{'.'.join(flattened)}' does not correspond to a table: '{toml}'"
+        raise KeyError(
+            f"Key provided corresponds to a value, not a table: {'.'.join(flattened)} = '{toml}'"
         )
 
     return toml, ".".join(flattened)
